@@ -204,6 +204,12 @@ void ITIPHandlerHelper::setDefaultAction(ITIPHandlerDialogDelegate::Action actio
     mDefaultAction = action;
 }
 
+void ITIPHandlerHelper::setMessagePrivacy(MessagePrivacyFlags messagePrivacy)
+{
+    m_scheduler->setSign((messagePrivacy & ITIPHandlerHelper::MessagePrivacySign) == ITIPHandlerHelper::MessagePrivacySign);
+    m_scheduler->setEncrypt((messagePrivacy & ITIPHandlerHelper::MessagePrivacyEncrypt) == ITIPHandlerHelper::MessagePrivacyEncrypt);
+}
+
 void ITIPHandlerHelper::sendIncidenceCreatedMessage(KCalendarCore::iTIPMethod method, const KCalendarCore::Incidence::Ptr &incidence)
 {
     /// When we created the incidence, we *must* be the organizer.
@@ -473,7 +479,7 @@ ITIPHandlerHelper::sendCounterProposal(const QString &receiver, const KCalendarC
 
         return sentInvitation(KMessageBox::ButtonCode::PrimaryAction, tmp, KCalendarCore::iTIPReply, receiver);
     } else {
-        return sentInvitation(KMessageBox::ButtonCode::PrimaryAction, newEvent, KCalendarCore::iTIPReply, receiver);
+        return sentInvitation(KMessageBox::ButtonCode::PrimaryAction, newEvent, KCalendarCore::iTIPCounter, receiver);
     }
 }
 
@@ -512,3 +518,5 @@ void ITIPHandlerHelper::slotSchedulerFinishDialog(const int result, KCalendarCor
         Q_EMIT finished(ResultFailKeepUpdate, QString());
     }
 }
+
+#include "moc_itiphandlerhelper_p.cpp"
